/*!
 * Copyright 2019, OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Tracer, Plugin, Logger, PluginConfig, PluginInternalFiles } from '@opentelemetry/types';
/** This class represent the base to patch plugin. */
export declare abstract class BasePlugin<T> implements Plugin<T> {
    supportedVersions?: string[];
    readonly moduleName?: string;
    readonly version?: string;
    protected readonly _basedir?: string;
    protected _moduleExports: T;
    protected _tracer: Tracer;
    protected _logger: Logger;
    protected _internalFilesExports: {
        [module: string]: unknown;
    };
    protected readonly _internalFilesList?: PluginInternalFiles;
    protected _config: PluginConfig;
    enable(moduleExports: T, tracer: Tracer, logger: Logger, config?: PluginConfig): T;
    disable(): void;
    /**
     * @TODO: To avoid circular dependencies, internal file loading functionality currently
     * lives in BasePlugin. It is not meant to work in the browser and so this logic
     * should eventually be moved somewhere else where it makes more sense.
     * https://github.com/open-telemetry/opentelemetry-js/issues/285
     */
    private _loadInternalFilesExports;
    private _loadInternalModule;
    private _requireInternalFiles;
    protected abstract patch(): T;
    protected abstract unpatch(): void;
}
